#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Jul 26 15:41:39 2021

Script to load and plot modeled subglacial geology outcrop .stl files

@author: Anja Rutishauser
"""

import numpy as np

import matplotlib.pyplot as plt
from stl import mesh

# Set to colorblind friendly colormaps
import matplotlib.style as style
style.use('tableau-colorblind10')
#style.use('seaborn-colorblind')

#%% ========= DEFINE PATHS ====================================================
GeolUnits = ['pPe','Cm_rb','Oe','Ocb','Oct']

#%% ========= :Load Geological Unit files ====================================
fig = plt.figure()
ax = plt.axes(projection='3d')

for GUnit in GeolUnits:
    Geolfile = GUnit+'_Model.stl'
    print('load '+GUnit+' stl file')

    mesh_data = mesh.Mesh.from_file(Geolfile)
    v = np.vstack(mesh_data.vectors)
    v = np.unique(v, axis=0)
    
    ind = np.where(~np.isnan(v[:,2]))[0] # drop NaNs
    x = v[ind,0]
    y = v[ind,1]
    z = v[ind,2]
    ax.plot_trisurf(x,y,z, edgecolor='none')
